# CryptoRL
Fetching time series data of cryptocurrencies and using ML and RL to do cryptocurrency trading.

<img src="https://img.shields.io/github/license/ZiyiXia/CryptoRL" alt="CryptoRL MIT License"/>
<img src="https://img.shields.io/github/issues/ZiyiXia/CryptoRL" alt="Issue"/>
<img src="https://img.shields.io/github/actions/workflow/status/ZiyiXia/CryptoRL/build.yml?label=build%20status&logo=github" alt="built status">
<img src="https://img.shields.io/codecov/c/github/ZiyiXia/CryptoRL?logo=codecov" alt="codecov">

## Overview
CryptoRL will use popular deep reinforcement learning algorithms and machine learning algorithms to do cryptocurrency trading.

## Installation

Run ```pip install cryptorl``` to install CryptoRL.

## Usage

To fetch data, please use the functions in *data.py*.

With well processed data, you can use *env_crypto.py* to construct crypto market environment.